package com.yunzhi.demo.controller;

import com.yunzhi.demo.common.*;
import com.yunzhi.demo.entity.SysLogin;
import com.yunzhi.demo.entity.SysUser;
import com.yunzhi.demo.service.ISysLoginService;
import com.yunzhi.demo.service.ISysUserService;
import com.yunzhi.demo.vo.LoginParam;
import com.yunzhi.demo.vo.TokenParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;

//import java.util.HashMap;


@Api(tags = "登入/登出")
@RestController
public class LoginController extends BaseController {

    @Autowired
    ISysLoginService iSysLoginService;

    @Autowired
    ISysUserService iSysUserService;

    @PostMapping("/admin/login")
    @ApiOperation(value="登录", notes = "登录", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean login(@ApiParam("登录参数") @RequestBody LoginParam loginParam) throws Exception {
        if (null == loginParam) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String userName = loginParam.getUserName();
        String password = loginParam.getPassword();

        if (StringUtils.isEmpty(userName) || StringUtils.isEmpty(password)) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        SysLogin sysLogin = iSysLoginService.getByLoginName(userName);
        if (null == sysLogin) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        SysUser sysUser = iSysUserService.getById(sysLogin.getUserId());
        if (null == sysUser) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!checkPassword(password, sysLogin.getPassword(), sysLogin.getUserId())) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!Constants.STATUS_NORMAL.equals(sysUser.getStatus())) {
            return ResponseBean.error("用户状态不正确, 请联系管理人员", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 生成 token
        TokenParam tokenParam = new TokenParam()
                .setUserId(sysUser.getUserId())
                .setOrgId("0");
        String token = JWTUtils.encode(tokenParam.toMap());

        Map<String, Object> res = new HashMap<String, Object>() {{
            put("user", sysUser);
            put("token", token);
        }};
        return ResponseBean.success(res);
    }

    private boolean checkPassword(String src, String targ, String salt) {
        return EncryptUtils.md5(src, salt).equals(targ);
    }
}
