package com.yunzhi.demo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.demo.common.BaseController;
import com.yunzhi.demo.common.Constants;
import com.yunzhi.demo.common.ResponseBean;
import com.yunzhi.demo.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.demo.service.ITdSpecialtyService;
import com.yunzhi.demo.entity.TdSpecialty;

/**
 * <p>
    * 专业 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-04-15
 */

@Api(tags = "专业")
@RestController
@RequestMapping("/")
public class TdSpecialtyController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdSpecialtyController.class);

    @Autowired
    public ITdSpecialtyService iTdSpecialtyService;

    @GetMapping("/ma/specialty")
    @ApiOperation(value="小程序学科专业字典", notes = "学科专业", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean maSchoolList(@ApiParam(value = "学校ID", required = false) @RequestParam(value ="school", required = false) String school,
                                     @ApiParam(value = "名称", required = false) @RequestParam(value ="name", required = false) String name) throws Exception {
        QueryWrapper<TdSpecialty> queryWrapper = new QueryWrapper<TdSpecialty>()
                .eq(!StringUtils.isEmpty(school),"schoolId", school)
                .like(!StringUtils.isEmpty(name), "name", "%"+name+"%")
                .eq("status", Constants.STATUS_NORMAL)
                .orderByAsc("sort_no")
                .orderByDesc("create_date");

        return ResponseBean.success(iTdSpecialtyService.list(queryWrapper));
    }

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/tdSpecialty",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdSpecialtyList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TdSpecialty> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TdSpecialty> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TdSpecialty> result = iTdSpecialtyService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param tdSpecialty 实体对象
     * @return
     */
    @RequestMapping(value="/tdSpecialty",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean tdSpecialtyAdd(@ApiParam("保存内容") @RequestBody TdSpecialty tdSpecialty) throws Exception{

        if (iTdSpecialtyService.save(tdSpecialty)){
            return ResponseBean.success(tdSpecialty);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdSpecialty/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean tdSpecialtyDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTdSpecialtyService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdSpecialty 实体对象
     * @return
     */
    @RequestMapping(value="/tdSpecialty/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean tdSpecialtyUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TdSpecialty tdSpecialty) throws Exception{

        if (iTdSpecialtyService.updateById(tdSpecialty)){
            return ResponseBean.success(iTdSpecialtyService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdSpecialty/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdSpecialtyGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTdSpecialtyService.getById(id));
    }
}
